@@ -159,10 +159,11 @@ public class ActionCommand extends ControlOrActionCommand {
              * [":message" string]
              * <method: string>
              *
-             * only :message is supported
+             * only :message and :method are supported
              *
              */
             retval.put(":message", Integer.valueOf(1));
+            retval.put(":method", Integer.valueOf(1));
             return retval;
         }
 
